@@ -10,7 +10,7 @@ use re '/aa';
 use Carp;
 use Errno;
 
-our $VERSION = '1.00_03';
+our $VERSION = '1.00_04';
 our @ISA = qw(Exporter);
 our @EXPORT = qw(BACKUP_NONE
                  BACKUP_SINGLE
@@ -169,6 +169,7 @@ BEGIN {
     if (eval { symlink("",""); 1 }) {
 	*{rename_backup} = \&rename_backup_posix;
     } elsif ($^O eq 'MSWin32' && eval { require Win32::FileOp }) {
+	Win32::FileOp->import(qw(MoveFile));
 	*{rename_backup} = \&rename_backup_win32;
     } else {
 	warn "using last resort rename method susceptible to a race condition";
@@ -418,5 +419,17 @@ the file.  Otherwise, creates simple backup.
 
 Optional I<%opts> have the same meaning as in
 B<backup_copy>, except that, obviously, B<type> keyword is not accepted.    
-    
-=cut    
+
+=head1 LICENSE
+
+GPLv3+: GNU GPL version 3 or later, see
+L<http://gnu.org/licenses/gpl.html>.
+
+This  is  free  software:  you  are free to change and redistribute it.
+There is NO WARRANTY, to the extent permitted by law.
+
+=head1 AUTHORS
+
+Sergey Poznyakoff <gray@gnu.org>
+
+=cut
